from sports.nba.nba_team import NBA_Team


class ClevelandCavaliers(NBA_Team):
    """
    NBA Atlanta Hawks Static Information

    """
    full_name = "Cleveland Cavaliers"
    name = "Cavaliers"
    team_id = 1610612739

    def __init__(self):
        """
        """
        super().__init__()