from sports.nba.nba_team import NBA_Team


class MinnesotaTimberwolves(NBA_Team):
    """
    NBA Golden State Warriors Static Information

    """

    full_name = "Minnesota Timberwolves"
    name = "Timberwolves"
    team_id = 1610612750

    def __init__(self):
        """
        """
        super().__init__()

